@@ -2,7 +2,7 @@
 #
 # makealldists.pl - make all encoding distributions from Char
 #
-# Copyright (c) 2010, 2011, 2012, 2013, 2015 INABA Hitoshi <ina@cpan.org>
+# Copyright (c) 2010, 2011, 2012, 2013, 2015, 2018 INABA Hitoshi <ina@cpan.org>
 #
 ######################################################################
 
@@ -80,7 +80,7 @@ print "ok - 1\\n";
 exit;
 END
     close(TEST);
-    mysystem(qq{$^X test.pl});
+    mysystem(qq{$^X -Ilib test.pl});
 
     open(TEST,">test.pl") || die "Can't open file: test.pl, q(;_;)bad!!\n";
     binmode TEST;
@@ -93,14 +93,15 @@ print "ok - 1\\n";
 exit;
 END
     close(TEST);
-    mysystem(qq{$^X test.pl});
+    mysystem(qq{$^X -Ilib test.pl});
 
+    mkdir("$encoding/lib",0777);
     for my $file (
-        "$encoding.pm",
-        "E\L$encoding\E.pm",
+        "lib/$encoding.pm",
+        "lib/E\L$encoding\E.pm",
         'test.pl',
         'Changes',
-        'pMakefile.PL',
+        'pmake.bat',
     ){
         mycopy($file, "$encoding/$file");
     }
@@ -148,13 +149,13 @@ END
     binmode ENCODING_MANIFEST;
     for my $file (
         "Char/$encoding.pm",
-        "$encoding.pm",
-        "E\L$encoding\E.pm",
+        "lib/$encoding.pm",
+        "lib/E\L$encoding\E.pm",
         'README',
         'Changes',
         'META.yml',
         'Makefile.PL',
-        'pMakefile.PL',
+        'pmake.bat',
         'test.pl',
         'README2ND',
         'MANIFEST',
@@ -190,14 +191,8 @@ END
     close(ENCODING_MANIFEST);
 
     mychdir($encoding);
-    mysystem(qq{$^X pMakefile.PL});
-    if ($^O eq 'MSWin32') {
-        mysystem(qq{$^X pmake.bat dist});
-    }
-    else {
-        mysystem(qq{$^X ./pmake dist});
-    }
-    mysystem(qq{$^X test.pl});
+    mysystem(qq{$^X -x pmake.bat dist});
+    mysystem(qq{$^X -Ilib test.pl});
     mychdir('..');
 }
 
