@@ -1,6 +1,6 @@
 ######################################################################
 #
-# makeallt.pl - make all t-skeleton/dist/*.t scripts
+# makeallt.pl - make all t-skeleton/t/dist/*.t scripts
 #
 # Copyright (c) 2010, 2011, 2012, 2013, 2015 INABA Hitoshi <ina@cpan.org>
 #
@@ -17,57 +17,81 @@ makes test scripts of all dists from Sjis test script.
 END
 }
 
-for my $dist (
-    'Sjis',
-    'HP15',
-    'INFORMIXV6ALS',
-    'GB18030',
-    'GBK',
-    'UHC',
-    'KPS9566',
-    'Big5HKSCS',
-    'Big5Plus',
+my %scriptdir = (
+    'Arabic'        => 'xt',
+    'Big5HKSCS'     => 'xt',
+    'Big5Plus'      => 'xt',
+    'Cyrillic'      => 'xt',
+    'EUCJP'         =>  't',
+    'EUCTW'         => 'xt',
+    'GB18030'       => 'xt',
+    'GBK'           => 'xt',
+    'Greek'         => 'xt',
+    'HP15'          => 'xt',
+    'Hebrew'        => 'xt',
+    'INFORMIXV6ALS' => 'xt',
+    'JIS8'          => 'xt',
+    'KOI8R'         => 'xt',
+    'KOI8U'         => 'xt',
+    'KPS9566'       => 'xt',
+    'Latin1'        =>  't',
+    'Latin10'       => 'xt',
+    'Latin2'        => 'xt',
+    'Latin3'        => 'xt',
+    'Latin4'        => 'xt',
+    'Latin5'        => 'xt',
+    'Latin6'        => 'xt',
+    'Latin7'        => 'xt',
+    'Latin8'        => 'xt',
+    'Latin9'        => 'xt',
+    'OldUTF8'       => 'xt',
+### 'Sjis'          =>  't',
+    'TIS620'        => 'xt',
+    'UHC'           => 'xt',
+    'USASCII'       => 'xt',
+    'UTF2'          =>  't',
+    'Windows1252'   => 'xt',
+    'Windows1258'   => 'xt',
+);
 
-    'EUCJP',
-    'EUCTW',
+open(MANIFEST,">MANIFEST.add") || die "Can't open file: MANIFEST.add\n";
+binmode MANIFEST;
 
-    'OldUTF8',
-    'UTF2',
+for my $dist (sort keys %scriptdir) {
+    next if $dist eq 'Sjis';
 
-    'Cyrillic',
-    'Greek',
-    'KOI8R',
-    'KOI8U',
-    'Latin1',
-    'Latin10',
-    'Latin2',
-    'Latin3',
-    'Latin4',
-    'Latin5',
-    'Latin6',
-    'Latin7',
-    'Latin8',
-    'Latin9',
-    'Windows1252',
-    'Windows1258',
+    my @test = ();
+    if (opendir(DIR,qq{t/$dist})) {
+        push @test, map {"t/$dist/$_"} grep(/\.t$/i, readdir(DIR));
+        closedir(DIR);
+    }
+    if (opendir(DIR,qq{xt/$dist})) {
+        push @test, map {"xt/$dist/$_"} grep(/\.t$/i, readdir(DIR));
+        closedir(DIR);
+    }
 
-    'Arabic',
-    'Hebrew',
-    'JIS8',
-    'TIS620',
-    'USASCII',
-){
-    opendir(DIR,qq{t/$dist}) || die "Can't open dir: t/$dist\n";
-    my @test = grep(/\.t$/i, readdir(DIR));
-    closedir(DIR);
-    my($lasttest) = (sort @test)[-1];
+    my @head = ();
+    for my $test (reverse sort @test) {
+        open(TEST,$test) || die "Can't open file: $test\n";
+        @_ = <TEST>;
+        close(TEST);
+        @head = @_[0,1,2];
+        if (($head[0] =~ /^# encoding: .+$/) and
+            ($head[1] =~ /^# This file is encoded in .+$/) and
+            ($head[2] =~ /^die "This file is not encoded in .+$/)
+        ) {
+            last;
+        }
+    }
+    if (($head[0] =~ /^# encoding: .+$/) and
+        ($head[1] =~ /^# This file is encoded in .+$/) and
+        ($head[2] =~ /^die "This file is not encoded in .+$/)
+    ) {
+    }
+    else {
+        die "$dist head broken.\n";
+    }
 
-    open(TEST,"t/$dist/$lasttest") || die "Can't open file: t/$dist/$lasttest\n";
-    @_ = <TEST>;
-    close(TEST);
-    my @head = @_[0,1,2];
-
-    mkdir($dist, 0777);
     for my $test (@ARGV) {
         open(TEST,$test) || die "Can't open file: $test\n";
         binmode TEST;
@@ -118,16 +142,21 @@ END
         }
 
         mkdir(qq{t-skeleton},0777);
-        mkdir(qq{t-skeleton/$dist},0777);
-print STDERR "$test --> t-skeleton/$dist/$test\n";
-        open(TEST,qq{>t-skeleton/$dist/$test}) || die "Can't open file: t-skeleton/$dist/$test\n";
+        mkdir(qq{t-skeleton/$scriptdir{$dist}},0777);
+        mkdir(qq{t-skeleton/$scriptdir{$dist}/$dist},0777);
+
+        open(TEST,qq{>t-skeleton/$scriptdir{$dist}/$dist/$test}) || die "Can't open file: t-skeleton/$scriptdir{$dist}/$dist/$test\n";
         binmode TEST;
         print TEST @head;
         print TEST @_[3..$#_];
         close(TEST);
+
+        print MANIFEST "$scriptdir{$dist}/$dist/$test\n";
     }
 }
 
+close(MANIFEST);
+
 __END__
 
 =pod
